@@ -8,11 +8,18 @@
  * @brief Compiler entry point for building the JavaScript package. File imports
  *  using the `@` symbol are aliased to `lib/ui-library/src`.
  */
+
+// styles
+import '@/styles/_global.less';
+import '@/styles/tw-theme-vars.css';
+
 import PkpLoad from '../lib/pkp/js/load.js';
 
 // Import controllers used by OPS
 import Container from '@/components/Container/Container.vue';
+import AdvancedSearchReviewerContainer from '@/components/Container/AdvancedSearchReviewerContainer.vue';
 import Page from '@/components/Container/Page.vue';
+import WorkflowPageOPS from '@/pages/workflow/WorkflowPageOPS.vue';
 import AccessPage from '@/components/Container/AccessPage.vue';
 import AddContextContainer from '@/components/Container/AddContextContainer.vue';
 import AdminPage from '@/components/Container/AdminPage.vue';
@@ -27,29 +34,24 @@ import StatsPublicationsPage from '@/components/Container/StatsPublicationsPage.
 import StatsContextPage from '@/components/Container/StatsContextPage.vue';
 import StatsUsersPage from '@/components/Container/StatsUsersPage.vue';
 import SubmissionWizardPage from '@/components/Container/SubmissionWizardPageOPS.vue';
-import WorkflowPage from '@/components/Container/WorkflowPageOPS.vue';
-import JobsPage from '@/components/Container/JobsPage.vue';
-import FailedJobsPage from '@/components/Container/FailedJobsPage.vue';
-import FailedJobDetailsPage from '@/components/Container/FailedJobDetailsPage.vue';
 
-// Required by the URN plugin
-import FieldText from '@/components/Form/fields/FieldText.vue';
+// Helper for initializing and tracking Vue controllers
+import VueRegistry from '../lib/pkp/js/classes/VueRegistry.js';
+VueRegistry.registerComponent('WorkflowPage', WorkflowPageOPS);
 
 // Expose Vue, the registry and controllers in a global var
-window.pkp = Object.assign(PkpLoad, {
+window.pkp = Object.assign(PkpLoad, window.pkp || {}, {
 	controllers: {
 		Container,
 		Page,
 		AccessPage,
 		AddContextContainer,
 		AdminPage,
+		AdvancedSearchReviewerContainer,
 		DecisionPage,
 		DoiPage,
 		ImportExportPage,
 		ManageEmailsPage,
-		JobsPage,
-		FailedJobsPage,
-		FailedJobDetailsPage,
 		SettingsPage,
 		StartSubmissionPage,
 		StatsEditorialPage,
@@ -57,9 +59,5 @@ window.pkp = Object.assign(PkpLoad, {
 		StatsContextPage,
 		StatsUsersPage,
 		SubmissionWizardPage,
-		WorkflowPage,
 	},
 });
-
-// Required by the URN plugin
-window.pkp.Vue.component('field-text', FieldText);
