@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/queries/form/QueryForm.php
  *
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2014-2024 Simon Fraser University
+ * Copyright (c) 2003-2024 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class QueryForm
@@ -22,19 +22,22 @@ use APP\facades\Repo;
 use APP\template\TemplateManager;
 use Illuminate\Support\Facades\Mail;
 use PKP\controllers\grid\queries\traits\StageMailable;
-use PKP\core\Core;
 use PKP\core\PKPApplication;
 use PKP\core\PKPRequest;
-use PKP\db\DAORegistry;
 use PKP\form\Form;
-use PKP\note\NoteDAO;
-use PKP\notification\NotificationDAO;
+use PKP\form\validation\FormValidator;
+use PKP\form\validation\FormValidatorCSRF;
+use PKP\form\validation\FormValidatorCustom;
+use PKP\form\validation\FormValidatorPost;
+use PKP\note\Note;
+use PKP\notification\Notification;
 use PKP\query\Query;
-use PKP\query\QueryDAO;
+use PKP\query\QueryParticipant;
 use PKP\security\Role;
-use PKP\stageAssignment\StageAssignmentDAO;
+use PKP\stageAssignment\StageAssignment;
 use PKP\submission\reviewAssignment\ReviewAssignment;
-use PKP\submission\reviewAssignment\ReviewAssignmentDAO;
+use PKP\userGroup\UserGroup;
+use PKP\userGroup\relationships\UserUserGroup;
 
 class QueryForm extends Form
 {
@@ -70,47 +73,47 @@ class QueryForm extends Form
         parent::__construct('controllers/grid/queries/form/queryForm.tpl');
         $this->setStageId($stageId);
 
-        $queryDao = DAORegistry::getDAO('QueryDAO'); /** @var QueryDAO $queryDao */
         if (!$queryId) {
             $this->_isNew = true;
 
             // Create a query
-            $query = $queryDao->newDataObject();
-            $query->setAssocType($assocType);
-            $query->setAssocId($assocId);
-            $query->setStageId($stageId);
-            $query->setSequence(REALLY_BIG_NUMBER);
-            $queryDao->insertObject($query);
-            $queryDao->resequence($assocType, $assocId);
+            $query = Query::create([
+                'assocType' => $assocType,
+                'assocId' => $assocId,
+                'stageId' => $stageId,
+                'seq' => REALLY_BIG_NUMBER
+            ]);
+
+            Repo::query()->resequence($assocType, $assocId);
 
             // Add the current user as a participant by default.
-            $queryDao->insertParticipant($query->getId(), $request->getUser()->getId());
+            QueryParticipant::create([
+                'queryId' => $query->id,
+                'userId' => $request->getUser()->getId()
+            ]);
 
-            // Create a head note
-            $noteDao = DAORegistry::getDAO('NoteDAO'); /** @var NoteDAO $noteDao */
-            $headNote = $noteDao->newDataObject();
-            $headNote->setUserId($request->getUser()->getId());
-            $headNote->setAssocType(Application::ASSOC_TYPE_QUERY);
-            $headNote->setAssocId($query->getId());
-            $headNote->setDateCreated(Core::getCurrentDate());
-            $noteDao->insertObject($headNote);
+            Note::create([
+                'userId' =>  $request->getUser()->getId(),
+                'assocType' => Application::ASSOC_TYPE_QUERY,
+                'assocId' => $query->id,
+            ]);
         } else {
-            $query = $queryDao->getById($queryId, $assocType, $assocId);
+            $query = Query::find($queryId);
             assert(isset($query));
             // New queries will not have a head note.
-            $this->_isNew = !$query->getHeadNote();
+            $this->_isNew = !Repo::note()->getHeadNote($query->id);
         }
 
         $this->setQuery($query);
 
         // Validation checks for this form
-        $this->addCheck(new \PKP\form\validation\FormValidatorCustom($this, 'users', 'required', 'stageParticipants.notify.warning', function ($users) {
-            return count($users) > 1;
+        $this->addCheck(new FormValidatorCustom($this, 'users', 'required', 'stageParticipants.notify.warning', function ($users) {
+            return !empty($users) && count($users) > 1;
         }));
-        $this->addCheck(new \PKP\form\validation\FormValidator($this, 'subject', 'required', 'submission.queries.subjectRequired'));
-        $this->addCheck(new \PKP\form\validation\FormValidator($this, 'comment', 'required', 'submission.queries.messageRequired'));
-        $this->addCheck(new \PKP\form\validation\FormValidatorPost($this));
-        $this->addCheck(new \PKP\form\validation\FormValidatorCSRF($this));
+        $this->addCheck(new FormValidator($this, 'subject', 'required', 'submission.queries.subjectRequired'));
+        $this->addCheck(new FormValidator($this, 'comment', 'required', 'submission.queries.messageRequired'));
+        $this->addCheck(new FormValidatorPost($this));
+        $this->addCheck(new FormValidatorCSRF($this));
     }
 
     //
@@ -214,14 +217,15 @@ class QueryForm extends Form
      */
     public function initData()
     {
-        $queryDao = DAORegistry::getDAO('QueryDAO'); /** @var QueryDAO $queryDao */
         if ($query = $this->getQuery()) {
-            $headNote = $query->getHeadNote();
+            $headNote = Repo::note()->getHeadNote($query->id);
             $this->_data = [
-                'queryId' => $query->getId(),
-                'subject' => $headNote ? $headNote->getTitle() : null,
-                'comment' => $headNote ? $headNote->getContents() : null,
-                'userIds' => $queryDao->getParticipantIds($query->getId()),
+                'queryId' => $query->id,
+                'subject' => $headNote?->title,
+                'comment' => $headNote?->contents,
+                'userIds' => QueryParticipant::withQueryId($query->id)
+                    ->pluck('user_id')
+                    ->all(),
                 'template' => null,
             ];
         } else {
@@ -231,6 +235,28 @@ class QueryForm extends Form
         return parent::initData();
     }
 
+    /**
+     * Get the assigned roles for a user in a submission and stage.
+     */
+    private function getAssignedRoles($submissionId, $stageId, $userId)
+    {
+        $assignedRoles = [];
+        $usersAssignments = StageAssignment::with(['userGroup'])
+            ->withSubmissionIds([$submissionId])
+            ->withStageIds([$stageId])
+            ->withUserId($userId)
+            ->get();
+
+        foreach ($usersAssignments as $usersAssignment) {
+            $userGroup = $usersAssignment->userGroup;
+            if ($userGroup) {
+                $assignedRoles[] = $userGroup->roleId;
+            }
+        }
+
+        return $assignedRoles;
+    }
+
     /**
      * Fetch the form.
      *
@@ -243,27 +269,27 @@ class QueryForm extends Form
     public function fetch($request, $template = null, $display = false, $actionArgs = [])
     {
         $query = $this->getQuery();
-        $headNote = $query->getHeadNote();
+        $headNote = Repo::note()->getHeadNote($query->id);
         $user = $request->getUser();
         $context = $request->getContext();
 
         $templateMgr = TemplateManager::getManager($request);
         $templateMgr->assign([
             'isNew' => $this->_isNew,
-            'noteId' => $headNote->getId(),
+            'noteId' => $headNote->id,
             'actionArgs' => $actionArgs,
-            'csrfToken' => $request->getSession()->getCSRFToken(),
+            'csrfToken' => $request->getSession()->token(),
             'stageId' => $this->getStageId(),
-            'assocId' => $query->getAssocId(),
-            'assocType' => $query->getAssocType(),
+            'assocId' => $query->assocId,
+            'assocType' => $query->assocType,
         ]);
 
         // Queries only support Application::ASSOC_TYPE_SUBMISSION so far
-        if ($query->getAssocType() !== PKPApplication::ASSOC_TYPE_SUBMISSION) {
+        if ($query->assocType !== PKPApplication::ASSOC_TYPE_SUBMISSION) {
             return parent::fetch($request, $template, $display);
         }
 
-        $submission = Repo::submission()->get($query->getAssocId());
+        $submission = Repo::submission()->get($query->assocId);
 
         // Add the templates that can be used for this discussion
         $templateKeySubjectPairs = [];
@@ -285,57 +311,55 @@ class QueryForm extends Form
 
         $templateMgr->assign('templates', $templateKeySubjectPairs);
 
-        $stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /** @var StageAssignmentDAO $stageAssignmentDao */
-
         // Get currently selected participants in the query
-        $queryDao = DAORegistry::getDAO('QueryDAO'); /** @var QueryDAO $queryDao */
-        $assignedParticipants = $query->getId() ? $queryDao->getParticipantIds($query->getId()) : [];
+        $assignedParticipants = $query->id
+            ? QueryParticipant::withQueryId($query->id)->get()->map(fn($qp) => $qp->userId)->all()
+            : [];
 
         // Always include current user, even if not with a stage assignment
-        $includeUsers[] = $user->getId();
+        $includeUsers = [$user->getId()];
         $excludeUsers = null;
 
-        // When in review stage, include/exclude users depending on the current users role
+        // When in review stage, include/exclude users depending on the current user's role
         $reviewAssignments = [];
-        // Get current users roles
-        $assignedRoles = (function () use ($stageAssignmentDao, $query, $user) {
-            $assignedRoles = [];
-            $usersAssignments = $stageAssignmentDao->getBySubmissionAndStageId($query->getAssocId(), $query->getStageId(), null, $user->getId());
-            while ($usersAssignment = $usersAssignments->next()) {
-                $userGroup = Repo::userGroup()->get($usersAssignment->getUserGroupId());
-                $assignedRoles[] = $userGroup->getRoleId();
-            }
-            return $assignedRoles;
-        })();
+        // Get current user's roles
+        $assignedRoles = $this->getAssignedRoles($query->assocId, $query->stageId, $user->getId());
 
-        if ($query->getStageId() == WORKFLOW_STAGE_ID_EXTERNAL_REVIEW || $query->getStageId() == WORKFLOW_STAGE_ID_INTERNAL_REVIEW) {
+        if ($query->stageId == WORKFLOW_STAGE_ID_EXTERNAL_REVIEW || $query->stageId == WORKFLOW_STAGE_ID_INTERNAL_REVIEW) {
             // Get all review assignments for current submission
-            $reviewAssignmentDao = DAORegistry::getDAO('ReviewAssignmentDAO'); /** @var ReviewAssignmentDAO $reviewAssignmentDao */
-            $reviewAssignments = $reviewAssignmentDao->getBySubmissionId($submission->getId());
+            $reviewAssignments = Repo::reviewAssignment()->getCollector()->filterBySubmissionIds([$submission->getId()])->getMany();
 
             // if current user is editor/journal manager/site admin and not have author role , add all reviewers
-            if (array_intersect($assignedRoles, [Role::ROLE_ID_MANAGER, Role::ROLE_ID_SUB_EDITOR]) || (empty($assignedRoles) && ($user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()) || $user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE)))) {
+            if (
+                array_intersect($assignedRoles, [Role::ROLE_ID_MANAGER, Role::ROLE_ID_SUB_EDITOR]) ||
+                (empty($assignedRoles) && ($user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()) || $user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID)))
+            ) {
                 foreach ($reviewAssignments as $reviewAssignment) {
                     $includeUsers[] = $reviewAssignment->getReviewerId();
                 }
             }
 
-            // if current user is an anonymous reviewer, filter out authors
+            // if current user is an anonymous reviewer, exclude authors
             foreach ($reviewAssignments as $reviewAssignment) {
                 if ($reviewAssignment->getReviewerId() == $user->getId()) {
-                    if ($reviewAssignment->getReviewMethod() != ReviewAssignment::SUBMISSION_REVIEW_METHOD_OPEN) {
-                        $authorAssignments = $stageAssignmentDao->getBySubmissionAndRoleId($query->getAssocId(), Role::ROLE_ID_AUTHOR);
-                        while ($assignment = $authorAssignments->next()) {
-                            $excludeUsers[] = $assignment->getUserId();
-                        }
+                    if ($reviewAssignment->getReviewMethod() == ReviewAssignment::SUBMISSION_REVIEW_METHOD_DOUBLEANONYMOUS) {
+                        $excludeUsers = StageAssignment::withSubmissionIds([$query->assocId])
+                            ->withRoleIds([Role::ROLE_ID_AUTHOR])
+                            ->get()
+                            ->map(fn($assignment) => $assignment->userId)
+                            ->all();
                     }
                 }
             }
 
-            // if current user is author, add open reviewers who have accepted the request
+            // If current user is author, include open reviewers who have accepted the request
             if (array_intersect([Role::ROLE_ID_AUTHOR], $assignedRoles)) {
                 foreach ($reviewAssignments as $reviewAssignment) {
-                    if ($reviewAssignment->getReviewMethod() == ReviewAssignment::SUBMISSION_REVIEW_METHOD_OPEN && $reviewAssignment->getDateConfirmed() && !$reviewAssignment->getDeclined()) {
+                    if (
+                        $reviewAssignment->getReviewMethod() == ReviewAssignment::SUBMISSION_REVIEW_METHOD_OPEN &&
+                        $reviewAssignment->getDateConfirmed() &&
+                        !$reviewAssignment->getDeclined()
+                    ) {
                         $includeUsers[] = $reviewAssignment->getReviewerId();
                     }
                 }
@@ -346,7 +370,7 @@ class QueryForm extends Form
             ->filterByContextIds([$context->getId()])
             ->limit(100)
             ->offset(0)
-            ->assignedTo($query->getAssocId(), $query->getStageId())
+            ->assignedTo($query->assocId, $query->stageId)
             ->excludeUserIds($excludeUsers)
             ->getMany();
 
@@ -354,28 +378,38 @@ class QueryForm extends Form
         $usersIterator = $usersIterator->merge($includedUsersIterator);
 
         $allParticipants = [];
-        foreach ($usersIterator as $user) {
-            $allUserGroups = Repo::userGroup()->userUserGroups($user->getId(), $context->getId());
-
+        foreach ($usersIterator as $participantUser) {
+            // fetch user groups where the user is assigned in the current context
+            $allUserGroups = UserGroup::query()
+            ->withContextIds($context->getId())
+            ->whereHas('userUserGroups', function ($query) use ($participantUser) {
+                $query->withUserId($participantUser->getId())
+                      ->withActive();
+            })
+            ->get();
+    
             $userRoles = [];
-            $userAssignments = $stageAssignmentDao->getBySubmissionAndStageId($query->getAssocId(), $query->getStageId(), null, $user->getId())->toArray();
-            foreach ($userAssignments as $userAssignment) {
+            // get participant's assigned roles
+            $participantAssignedRoles = $this->getAssignedRoles($query->assocId, $query->stageId, $participantUser->getId());
+
+            foreach ($participantAssignedRoles as $roleId) {
                 foreach ($allUserGroups as $userGroup) {
-                    if ($userGroup->getId() == $userAssignment->getUserGroupId()) {
-                        $userRoles[] = $userGroup->getLocalizedName();
+                    if ($userGroup->roleId == $roleId) {
+                        $userRoles[] = $userGroup->getLocalizedData('name');
                     }
                 }
             }
+            // include reviewer roles if applicable
             foreach ($reviewAssignments as $assignment) {
-                if ($assignment->getReviewerId() == $user->getId()) {
+                if ($assignment->getReviewerId() == $participantUser->getId()) {
                     $userRoles[] = __('user.role.reviewer') . ' (' . __($assignment->getReviewMethodKey()) . ')';
                 }
             }
             if (!count($userRoles)) {
                 $userRoles[] = __('submission.status.unassigned');
             }
-            $allParticipants[$user->getId()] = __('submission.query.participantTitle', [
-                'fullName' => $user->getFullName(),
+            $allParticipants[$participantUser->getId()] = __('submission.query.participantTitle', [
+                'fullName' => $participantUser->getFullName(),
                 'userGroup' => join(__('common.commaListSeparator'), $userRoles),
             ]);
         }
@@ -384,7 +418,7 @@ class QueryForm extends Form
         $allowedEditTimeNotice = ['show' => false, 'limit' => 60];
         if (array_intersect($assignedRoles, [Role::ROLE_ID_ASSISTANT, Role::ROLE_ID_AUTHOR, Role::ROLE_ID_REVIEWER])) {
             $allowedEditTimeNotice['show'] = true;
-            $allowedEditTimeNotice['limit'] = (int) ($allowedEditTimeNotice['limit'] - (time() - strtotime($headNote->getDateCreated())) / 60);
+            $allowedEditTimeNotice['limit'] = (int) ($allowedEditTimeNotice['limit'] - $headNote->dateCreated->diffInMinutes());
         }
 
         $templateMgr->assign([
@@ -424,42 +458,37 @@ class QueryForm extends Form
         // In other stages validate that participants are assigned to that stage.
         $query = $this->getQuery();
         // Queries only support Application::ASSOC_TYPE_SUBMISSION so far (see above)
-        if ($query->getAssocType() == Application::ASSOC_TYPE_SUBMISSION) {
+        if ($query->assocType == Application::ASSOC_TYPE_SUBMISSION) {
             $request = Application::get()->getRequest();
             $user = $request->getUser();
             $context = $request->getContext();
-            $submissionId = $query->getAssocId();
-            $stageId = $query->getStageId();
-
-            $reviewAssignmentDao = DAORegistry::getDAO('ReviewAssignmentDAO'); /** @var ReviewAssignmentDAO $reviewAssignmentDao */
-            $stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /** @var StageAssignmentDAO $stageAssignmentDao */
+            $submissionId = $query->assocId;
+            $stageId = $query->stageId;
 
             // get the selected participants
             $newParticipantIds = (array) $this->getData('users');
             $participantsToConsider = $blindReviewerCount = 0;
             foreach ($newParticipantIds as $participantId) {
                 // get participant roles in this workflow stage
-                $assignedRoles = [];
-                $usersAssignments = $stageAssignmentDao->getBySubmissionAndStageId($submissionId, $stageId, null, $participantId);
-                while ($usersAssignment = $usersAssignments->next()) {
-                    $userGroup = Repo::userGroup()->get($usersAssignment->getUserGroupId());
-                    $assignedRoles[] = $userGroup->getRoleId();
-                }
-
+                $assignedRoles = $this->getAssignedRoles($submissionId, $stageId, $participantId);
                 if ($stageId == WORKFLOW_STAGE_ID_EXTERNAL_REVIEW || $stageId == WORKFLOW_STAGE_ID_INTERNAL_REVIEW) {
                     // validate the anonymity
                     // get participant review assignments
-                    $reviewAssignments = $reviewAssignmentDao->getBySubmissionReviewer($submissionId, $participantId, $stageId);
+                    $reviewAssignments = Repo::reviewAssignment()->getCollector()
+                        ->filterBySubmissionIds([$submissionId])
+                        ->filterByReviewerIds([$participantId])
+                        ->filterByStageId($stageId)
+                        ->getMany();
+
                     // if participant has no role in this stage and is not a reviewer
-                    if (empty($assignedRoles) && empty($reviewAssignments)) {
+                    if (empty($assignedRoles) && $reviewAssignments->isEmpty()) {
                         // if participant is current user and the user has admin or manager role, ignore participant
-                        if (($participantId == $user->getId()) && ($user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE) || $user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()))) {
+                        if ($participantId == $user->getId() && ($user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID) || $user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()))) {
                             continue;
-                        } else {
-                            $this->addError('users', __('editor.discussion.errorNotStageParticipant'));
-                            $this->addErrorField('users');
-                            break;
                         }
+                        $this->addError('users', __('editor.discussion.errorNotStageParticipant'));
+                        $this->addErrorField('users');
+                        break;
                     }
                     // is participant a blind reviewer
                     $blindReviewer = false;
@@ -480,18 +509,14 @@ class QueryForm extends Form
                         $this->addErrorField('users');
                         break;
                     }
-                } else {
-                    // if participant has no role/assignment in the current stage
-                    if (empty($assignedRoles)) {
-                        // if participant is current user and the user has admin or manager role, ignore participant
-                        if (($participantId == $user->getId()) && ($user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE) || $user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()))) {
-                            continue;
-                        } else {
-                            $this->addError('users', __('editor.discussion.errorNotStageParticipant'));
-                            $this->addErrorField('users');
-                            break;
-                        }
+                } elseif (empty($assignedRoles)) { // if participant has no role/assignment in the current stage
+                    // if participant is current user and the user has admin or manager role, ignore participant
+                    if (($participantId == $user->getId()) && ($user->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID) || $user->hasRole([Role::ROLE_ID_MANAGER], $context->getId()))) {
+                        continue;
                     }
+                    $this->addError('users', __('editor.discussion.errorNotStageParticipant'));
+                    $this->addErrorField('users');
+                    break;
                 }
             }
         }
@@ -503,37 +528,43 @@ class QueryForm extends Form
      */
     public function execute(...$functionArgs)
     {
-        $request = Application::get()->getRequest();
-        $queryDao = DAORegistry::getDAO('QueryDAO'); /** @var QueryDAO $queryDao */
         $query = $this->getQuery();
 
-        $headNote = $query->getHeadNote();
-        $headNote->setTitle($this->getData('subject'));
-        $headNote->setContents($this->getData('comment'));
+        $headNote = Repo::note()->getHeadNote($query->id);
+        $headNote->title = $this->getData('subject');
+        $headNote->contents = $this->getData('comment');
+        $headNote->save();
 
-        $noteDao = DAORegistry::getDAO('NoteDAO'); /** @var NoteDAO $noteDao */
-        $noteDao->updateObject($headNote);
-
-        $queryDao->updateObject($query);
+        $query->update();
 
         // Update participants
-        $oldParticipantIds = $queryDao->getParticipantIds($query->getId());
+        $oldParticipantIds = QueryParticipant::withQueryId($query->id)
+            ->pluck('user_id')
+            ->all();
+
         $newParticipantIds = $this->getData('users');
-        $queryDao->removeAllParticipants($query->getId());
+        QueryParticipant::withQueryId($query->id)
+            ->delete();
+        $addParticipants = [];
         foreach ($newParticipantIds as $userId) {
-            $queryDao->insertParticipant($query->getId(), $userId);
+            $addParticipants[] = ([
+                'query_id' => $query->id,
+                'user_id' => $userId
+            ]);
         }
+        QueryParticipant::insert($addParticipants);
 
         $removed = array_diff($oldParticipantIds, $newParticipantIds);
         foreach ($removed as $userId) {
             // Delete this users' notifications relating to this query
-            $notificationDao = DAORegistry::getDAO('NotificationDAO'); /** @var NotificationDAO $notificationDao */
-            $notificationDao->deleteByAssoc(Application::ASSOC_TYPE_QUERY, $query->getId(), $userId);
+            Notification::withAssoc(Application::ASSOC_TYPE_QUERY, $query->id)
+                ->withUserId($userId)
+                ->delete();
         }
 
         // Stamp the submission status modification date.
-        if ($query->getAssocType() == Application::ASSOC_TYPE_SUBMISSION) {
-            $submission = Repo::submission()->get($query->getAssocId());
+        if ($query->assocType == Application::ASSOC_TYPE_SUBMISSION) {
+            $submission = Repo::submission()->get($query->assocId);
             $submission->stampLastActivity();
             Repo::submission()->dao->update($submission);
         }
