@@ -12,28 +12,23 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_management
+ *
  * @brief Handle requests for settings pages.
  *
  */
 
 switch ($op) {
-	//
-	// Settings
-	//
-	case 'index':
-	case 'settings':
-	case 'access':
-		import('pages.management.SettingsHandler');
-		define('HANDLER_CLASS', 'SettingsHandler');
-		break;
-	case 'tools':
-	case 'importexport':
-	case 'statistics':
-	case 'permissions':
-	case 'resetPermissions':
-		import('lib.pkp.pages.management.PKPToolsHandler');
-		define('HANDLER_CLASS', 'PKPToolsHandler');
-		break;
+    //
+    // Settings
+    //
+    case 'index':
+    case 'settings':
+    case 'access':
+        return new APP\pages\management\SettingsHandler();
+    case 'tools':
+    case 'importexport':
+    case 'statistics':
+    case 'permissions':
+    case 'resetPermissions':
+        return new PKP\pages\management\PKPToolsHandler();
 }
-
-
