@@ -15,9 +15,11 @@
 namespace APP\plugins\generic\crossref\filter;
 
 use APP\core\Application;
+use APP\core\Request;
 use APP\plugins\generic\crossref\CrossrefExportDeployment;
 use APP\publication\Publication;
 use DOMDocument;
+use PKP\core\Dispatcher;
 use PKP\i18n\LocaleConversion;
 use PKP\submission\PKPSubmission;
 
@@ -155,7 +157,7 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
 
         $postedContentNode = $doc->createElementNS($deployment->getNamespace(), 'posted_content');
         $postedContentNode->setAttribute('type', 'preprint');
-        $postedContentNode->setAttribute('language', LocaleConversion::getIso1FromLocale($locale));
+        $postedContentNode->setAttribute('language', \Locale::getPrimaryLanguage($locale));
 
         // contributors
         $authors = $publication->getData('authors');
@@ -177,14 +179,40 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
 
                 // Check if both givenName and familyName is set for the submission language.
                 if (!empty($familyNames[$locale]) && !empty($givenNames[$locale])) {
-                    $personNameNode->setAttribute('language', LocaleConversion::getIso1FromLocale($locale));
+                    $personNameNode->setAttribute('language', \Locale::getPrimaryLanguage($locale));
                     $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'given_name', htmlspecialchars(ucfirst($givenNames[$locale]), ENT_COMPAT, 'UTF-8')));
                     $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'surname', htmlspecialchars(ucfirst($familyNames[$locale]), ENT_COMPAT, 'UTF-8')));
 
-                    if ($author->getData('orcid')) {
-                        $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'ORCID', $author->getData('orcid')));
-                    }
+                } else {
+                    $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'surname', htmlspecialchars(ucfirst($givenNames[$locale]), ENT_COMPAT, 'UTF-8')));
+                }
 
+                $affiliations = $author->getAffiliations();
+                if (count($affiliations) > 0) {
+                    $affiliationsNode = $doc->createElementNS($deployment->getNamespace(), 'affiliations');
+                    foreach ($affiliations as $affiliation) {
+                        $institutionNode = $doc->createElementNS($deployment->getNamespace(), 'institution');
+                        $institutionNameNode = $doc->createElementNS($deployment->getNamespace(), 'institution_name', htmlspecialchars($affiliation->getLocalizedName($locale), ENT_COMPAT, 'UTF-8'));
+                        $institutionNode->appendChild($institutionNameNode);
+                        $rorId = $affiliation->getRor();
+                        if ($rorId) {
+                            $institutionIdNode = $doc->createElementNS($deployment->getNamespace(), 'institution_id', $rorId);
+                            $institutionIdNode->setAttribute('type', 'ror');
+                            $institutionNode->appendChild($institutionIdNode);
+                        }
+                        $affiliationsNode->appendChild($institutionNode);
+                    }
+                    $personNameNode->appendChild($affiliationsNode);
+                }
+
+                if ($author->getData('orcid')) {
+                    $orcidNode = $doc->createElementNS($deployment->getNamespace(), 'ORCID', $author->getData('orcid'));
+                    $orcidAuthenticated = $author->getData('orcidIsVerified') ? 'true' : 'false';
+                    $orcidNode->setAttribute('authenticated', $orcidAuthenticated);
+                    $personNameNode->appendChild($orcidNode);
+                }
+
+                if (!empty($familyNames[$locale]) && !empty($givenNames[$locale])) {
                     $hasAltName = false;
                     foreach ($familyNames as $otherLocal => $familyName) {
                         if ($otherLocal != $locale && isset($familyName) && !empty($familyName)) {
@@ -195,7 +223,7 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
                             }
 
                             $nameNode = $doc->createElementNS($deployment->getNamespace(), 'name');
-                            $nameNode->setAttribute('language', LocaleConversion::getIso1FromLocale($otherLocal));
+                            $nameNode->setAttribute('language', \Locale::getPrimaryLanguage($otherLocal));
 
                             $nameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'surname', htmlspecialchars(ucfirst($familyName), ENT_COMPAT, 'UTF-8')));
                             if (isset($givenNames[$otherLocal]) && !empty($givenNames[$otherLocal])) {
@@ -205,11 +233,6 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
                             $altNameNode->appendChild($nameNode);
                         }
                     }
-                } else {
-                    $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'surname', htmlspecialchars(ucfirst($givenNames[$locale]), ENT_COMPAT, 'UTF-8')));
-                    if ($author->getData('orcid')) {
-                        $personNameNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'ORCID', $author->getData('orcid')));
-                    }
                 }
 
                 $contributorsNode->appendChild($personNameNode);
@@ -218,14 +241,13 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
             $postedContentNode->appendChild($contributorsNode);
         }
 
-
         // Titles
         $titlesNode = $doc->createElementNS($deployment->getNamespace(), 'titles');
         $titlesNode->appendChild($node = $doc->createElementNS($deployment->getNamespace(), 'title'));
-        $node->appendChild($doc->createTextNode($publication->getLocalizedTitle($submission->getLocale(), 'html')));
-        if ($subtitle = $publication->getLocalizedSubTitle($submission->getLocale(), 'html')) {
+        $node->appendChild($doc->createTextNode($publication->getLocalizedTitle($submission->getData('locale'), 'html')));
+        if ($subtitle = $publication->getLocalizedSubTitle($submission->getData('locale'), 'html')) {
             $titlesNode->appendChild($node = $doc->createElementNS($deployment->getNamespace(), 'subtitle'));
-            $node->appendChild($doc->createTextNode($subtitle));
+            $node->appendChild($doc->createTextNode($publication->getLocalizedTitle($subtitle, 'html')));
         }
         $postedContentNode->appendChild($titlesNode);
 
@@ -236,7 +258,7 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
         $abstracts = $publication->getData('abstract') ?: [];
         foreach($abstracts as $lang => $abstract) {
             $abstractNode = $doc->createElementNS($deployment->getJATSNamespace(), 'jats:abstract');
-            $abstractNode->setAttributeNS($deployment->getXMLNamespace(), 'xml:lang', LocaleConversion::getIso1FromLocale($lang));
+            $abstractNode->setAttributeNS($deployment->getXMLNamespace(), 'xml:lang', LocaleConversion::toBcp47($lang));
             $abstractNode->appendChild($doc->createElementNS($deployment->getJATSNamespace(), 'jats:p', htmlspecialchars(html_entity_decode(strip_tags($abstract), ENT_COMPAT, 'UTF-8'), ENT_COMPAT, 'utf-8')));
             $postedContentNode->appendChild($abstractNode);
         }
@@ -267,7 +289,7 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
 
         // DOI data
         $dispatcher = $this->_getDispatcher($request);
-        $url = $dispatcher->url($request, Application::ROUTE_PAGE, null, 'preprint', 'view', [$submission->getBestId(), 'version', $publication->getId()], null, null, true);
+        $url = $dispatcher->url($request, Application::ROUTE_PAGE, null, 'preprint', 'view', [$submission->getCurrentPublication()->getData('urlPath') ?? $submission->getId(), 'version', $publication->getId()], null, null, true, '');
         $postedContentNode->appendChild($this->createDOIDataNode($doc, $publication->getDoi(), $url));
 
         return $postedContentNode;
@@ -361,7 +383,7 @@ class PreprintCrossrefXmlFilter extends \PKP\plugins\importexport\native\filter\
      *
      *
      */
-    protected function _getDispatcher(\APP\core\Request $request): \PKP\core\Dispatcher
+    protected function _getDispatcher(Request $request): Dispatcher
     {
         $dispatcher = $request->getDispatcher();
         if ($dispatcher === null) {
